OSSP CVS Repository

ossp - Check-in [3939]
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [Patchset]  [Tagging/Branching

Check-in Number: 3939
Date: 2003-Jan-23 15:38:47 (local)
2003-Jan-23 14:38:47 (UTC)
User:ms
Branch:
Comment: Fix current file overwriting bug.
Tickets:
Inspections:
Files:
ossp-pkg/as/as-gui/as_slot.cpp      1.82 -> 1.83     2 inserted, 1 deleted

ossp-pkg/as/as-gui/as_slot.cpp 1.82 -> 1.83

--- as_slot.cpp  2003/01/22 23:57:01     1.82
+++ as_slot.cpp  2003/01/23 14:38:47     1.83
@@ -387,7 +387,8 @@
             }
         }
         else
-            saveFile(); // Finish off by calling the save action
+            this->setFilename(Filestring);  // Set filename of object first
+            this->saveFile();               // Finish by calling the save action
     }
     else {
         // User did not select a valid file and push okay button

CVSTrac 2.0.1